#[non_exhaustive]pub struct AddrFilter {
pub allow_benchmarking_v4: bool,
}Expand description
Filters out certain types of socket addresses which are unlikely to belong to valid peers (e.g., addresses from reserved ranges, etc…)
Using non-default filter typically only makes sense for testing (e.g., when using patchbay which allocates IPs from the “benchmarking” range).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.allow_benchmarking_v4: boolWhether
benchmarking
IPv4 addresses are allowed. Default is false.
Implementations
Sourceimpl AddrFilter
impl AddrFilter
pub fn allow_benchmarking_v4(self) -> Self