Struct TopicId
pub struct TopicId(/* private fields */);Expand description
Identified of a network stream topic.
When two connected peers open a stream with the same topic id, they can communicate over it with each other.
Implementations
impl TopicId
impl TopicId
pub const SIZE: usize = 32
pub fn generate<R>(rng: &mut R) -> TopicIdwhere
R: Rng,
pub fn generate<R>(rng: &mut R) -> TopicIdwhere
R: Rng,
Generates random topic id using the provided RNG.
pub fn random() -> TopicId
pub fn random() -> TopicId
Generates random topic id using rand::thread_rng().
pub fn as_bytes(&self) -> &[u8] ⓘ
pub fn from_slice_lossy(slice: &[u8]) -> TopicId
pub fn from_slice_lossy(slice: &[u8]) -> TopicId
Creates topic id from the given byte slice. If the slice is longer than Self::SIZE, it’s
truncated. If it’s shorter, it’s filled in with zeroes.